import React from "react";
import styles from "./Button.chroma.module.css";
import { Button, createButton, createEmbeddedButton } from "@react-components/button";
import { SIZE } from "@react-components/shared";
import { createChromaticSection, paramsBuilder, storiesOfBuilder } from "@utils";
import { createTestSuite } from "./createTestSuite";
import { isNil } from "lodash";

function stories(segment) {
  return storiesOfBuilder(module, createChromaticSection("Button")).segment(segment).parameters(paramsBuilder().canvasLayout({
    width: "80%"
  }).chromaticDelay(100).build()).build();
}

createTestSuite( /*#__PURE__*/React.createElement(Button, null), stories("/standard"));
createTestSuite( /*#__PURE__*/React.createElement(Button, {
  primary: true
}), stories("/primary"));
createTestSuite( /*#__PURE__*/React.createElement(Button, {
  secondary: true
}), stories("/secondary"));
createTestSuite( /*#__PURE__*/React.createElement(Button, {
  positive: true
}), stories("/positive"));
createTestSuite( /*#__PURE__*/React.createElement(Button, {
  negative: true
}), stories("/negative"));
createTestSuite( /*#__PURE__*/React.createElement(Button, {
  link: true
}), stories("/link")).add("secondary", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Button, {
  link: true,
  secondary: true,
  className: "mr5"
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  link: true,
  secondary: true,
  active: true,
  className: "mr5"
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  link: true,
  secondary: true,
  focus: true,
  className: "mr5"
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  link: true,
  secondary: true,
  hover: true,
  className: "mr5"
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  link: true,
  secondary: true,
  focus: true,
  hover: true
}, "Button")));
createTestSuite( /*#__PURE__*/React.createElement(Button, {
  naked: true
}), stories("/naked")).add("coloured", () => /*#__PURE__*/React.createElement("div", {
  className: "flex flex-column"
}, /*#__PURE__*/React.createElement("div", {
  className: "flex mb5"
}, /*#__PURE__*/React.createElement(Button, {
  className: "".concat(styles.button, " mr5"),
  naked: true,
  style: {
    backgroundColor: "#FCD5BC",
    boxShadow: "0px 0px 0px 1px #FCD003 inset"
  }
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  active: true,
  className: "".concat(styles.button, " mr5"),
  naked: true
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  disabled: true,
  className: styles.button,
  naked: true
}, "Button")), /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Button, {
  className: "".concat(styles.button, " mr5"),
  circular: true,
  naked: true,
  style: {
    backgroundColor: "#FCD5BC",
    boxShadow: "0px 0px 0px 1px #FCD003 inset"
  }
}, "Aa"), /*#__PURE__*/React.createElement(Button, {
  active: true,
  className: "".concat(styles.button, " mr5"),
  circular: true,
  naked: true
}, "Aa"), /*#__PURE__*/React.createElement(Button, {
  disabled: true,
  className: styles.button,
  circular: true,
  naked: true
}, "Aa"))));
stories().add("fluid", () => /*#__PURE__*/React.createElement("div", {
  className: "flex flex-column"
}, /*#__PURE__*/React.createElement("div", {
  className: "mb5"
}, /*#__PURE__*/React.createElement(Button, {
  fluid: true
}, "Button")), /*#__PURE__*/React.createElement("div", {
  className: "w-10"
}, /*#__PURE__*/React.createElement(Button, {
  fluid: true
}, "Button"))));

function setRedBackground(element) {
  if (!isNil(element)) {
    element.classList.add("bg-red");
  }
}

stories("/shorthands").add("element", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, createButton( /*#__PURE__*/React.createElement(Button, {
  className: "mr5"
}, "Button")), createButton( /*#__PURE__*/React.createElement(Button, {
  ref: setRedBackground
}, "Button")))).add("object", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, createButton({
  content: "Button",
  className: "mr5"
}), createButton({
  content: "Button",
  ref: setRedBackground
}))).add("string", () => createButton("Button")).add("embedded", () => /*#__PURE__*/React.createElement("div", {
  className: "flex items-end"
}, createEmbeddedButton({
  content: "Button",
  className: "mr5"
}, {
  size: SIZE.micro
}), createEmbeddedButton({
  content: "Button",
  className: "mr5"
}, {
  size: SIZE.mini
}), createEmbeddedButton({
  content: "Button",
  className: "mr5"
}, {
  size: SIZE.tiny
}), createEmbeddedButton({
  content: "Button",
  className: "mr5"
}, {
  size: SIZE.small
}), createEmbeddedButton({
  content: "Button",
  className: "mr5"
}), createEmbeddedButton({
  content: "Button"
}, {
  size: SIZE.large
})));