import React from "react";
import { Button } from "../../button";
import { CalendarIcon, CrossIcon } from "../../icons";
import { KEYS, SIZE, isNilOrEmpty } from "../../shared";
import { PureComponent, forwardRef } from "react";
import { TextInput } from "../../text-input";
import { bool, func, object, oneOf, oneOfType, string } from "prop-types";
import { isNil } from "lodash";
export class InnerDatePickerTextboxInput extends PureComponent {
  constructor(...args) {
    super(...args);

    this.handleKeyDown = event => {
      const {
        onKeyDown,
        onClear,
        open
      } = this.props;

      if (event.keyCode === KEYS.esc) {
        if (!open) {
          onClear(event);
        }
      }

      if (!isNil(onKeyDown)) {
        onKeyDown(event);
      }
    };
  }

  isPlaceholder() {
    const {
      value
    } = this.props;
    return isNilOrEmpty(value);
  }

  renderClearButton() {
    const {
      onClear,
      allowClear,
      open
    } = this.props;

    if (!allowClear || this.isPlaceholder() || open) {
      return null;
    }

    return /*#__PURE__*/React.createElement(Button, {
      icon: /*#__PURE__*/React.createElement(CrossIcon, null),
      onClick: onClear
    });
  }

  render() {
    const {
      value,
      onClick,
      onFocus,
      onBlur,
      placeholder,
      size,
      disabled,
      fluid,
      active,
      focus,
      hover,
      className,
      forwardedRef
    } = this.props;
    return /*#__PURE__*/React.createElement(TextInput, {
      onClick: onClick,
      onKeyDown: this.handleKeyDown,
      onFocus: onFocus,
      onBlur: onBlur,
      value: value,
      placeholder: placeholder,
      icon: /*#__PURE__*/React.createElement(CalendarIcon, null),
      iconPosition: "left",
      button: this.renderClearButton(),
      size: size,
      disabled: disabled,
      fluid: fluid,
      active: active,
      focus: focus,
      hover: hover,
      readOnly: true,
      tabIndex: disabled ? "-1" : "0",
      autoComplete: "off",
      className: className,
      ref: forwardedRef
    });
  }

}
InnerDatePickerTextboxInput.displayName = "InnerDatePickerTextboxInput";
InnerDatePickerTextboxInput.propTypes = {
  value: string.isRequired,
  onClick: func,
  onKeyDown: func,
  onFocus: func,
  onBlur: func,
  onClear: func,
  allowClear: bool,
  placeholder: string,
  fluid: bool,
  open: bool,
  active: bool,
  focus: bool,
  hover: bool,
  size: oneOf([SIZE.small, SIZE.medium, SIZE.large]),
  className: string,
  forwardedRef: oneOfType([object, func])
};
InnerDatePickerTextboxInput.defaultProps = {
  allowClear: true,
  placeholder: "Pick a date",
  size: SIZE.medium
};
export const DatePickerTextboxInput = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerDatePickerTextboxInput, Object.assign({}, props, {
  forwardedRef: ref
})));