import React from "react";
import { DatePickerCalendar } from "../date-picker-calendar";
import { DayPickerSingleDateController } from "../react-dates-wrapper";
import { PureComponent, cloneElement, forwardRef } from "react";
import { bool, element, func, number, oneOfType } from "prop-types";
import { momentObj as momentType } from "react-moment-proptypes";
import moment from "moment";
export class InnerSingleDatePickerCalendar extends PureComponent {
  constructor(...args) {
    super(...args);
    this.state = {
      focused: true
    };

    this.handleDateChange = date => {
      const {
        onDateChange
      } = this.props;
      onDateChange(date);
    };

    this.handleFocusChange = ({
      focused
    }) => {
      this.setState({
        focused
      });
    };

    this.handleClear = () => {
      const {
        onDateChange
      } = this.props;
      onDateChange(null);
    };

    this.handleApply = event => {
      const {
        onApply
      } = this.props;
      onApply(event);
    };
  }

  getInitialDate() {
    const {
      date
    } = this.props;
    return date || moment();
  }

  renderButtons() {
    const {
      date,
      allowClear,
      buttons
    } = this.props;
    return /*#__PURE__*/cloneElement(buttons, {
      date,
      onClear: this.handleClear,
      onApply: this.handleApply,
      allowClear
    });
  }

  renderCalendar() {
    const {
      date,
      reactDatesCalendar
    } = this.props;
    const {
      focused
    } = this.state;
    return /*#__PURE__*/cloneElement(reactDatesCalendar, {
      date: date,
      focused: focused,
      onDateChange: this.handleDateChange,
      onFocusChange: this.handleFocusChange
    });
  }

  render() {
    const {
      minDate,
      maxDate,
      initialVisibleMonth,
      numberOfMonths,
      className,
      forwardedRef
    } = this.props;
    return /*#__PURE__*/React.createElement(DatePickerCalendar, {
      calendar: this.renderCalendar(),
      buttons: this.renderButtons(),
      minDate: minDate,
      maxDate: maxDate,
      initialDate: this.getInitialDate(),
      initialVisibleMonth: initialVisibleMonth,
      numberOfMonths: numberOfMonths,
      className: className,
      ref: forwardedRef,
      temporarySingleDatePickerFlag: true
    });
  }

}
InnerSingleDatePickerCalendar.displayName = "InnerSingleDatePickerCalendar";
InnerSingleDatePickerCalendar.propTypes = {
  /**
   * A controlled date value.
   */
  date: momentType,

  /**
   * Called when the date is applied.
   * @param {Moment} date - Selected date.
   * @returns {void}
   */
  onDateChange: func,

  /**
   * Called on apply button click.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @returns {void}
   */
  onApply: func,

  /**
   * The minimum (inclusive) date available for selection.
   */
  minDate: momentType,

  /**
   * The maximum (inclusive) date available for selection.
   */
  maxDate: momentType,

  /**
   * An initial visible month displayed when the calendar open.
   */
  initialVisibleMonth: oneOfType([momentType, func]),

  /**
   * The number of months displayed simultaneously in the calendar.
   */
  numberOfMonths: number,

  /**
   * A React component displayed under the calendar to `clear` and `apply` the date(s).
   */
  buttons: element,

  /**
   * Whether or not the calendar selected date can be cleared.
   */
  allowClear: bool,

  /**
   * @ignore
   */
  reactDatesCalendar: element
};
InnerSingleDatePickerCalendar.defaultProps = {
  reactDatesCalendar: /*#__PURE__*/React.createElement(DayPickerSingleDateController, null)
};
export const SingleDatePickerCalendar = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerSingleDatePickerCalendar, Object.assign({}, props, {
  forwardedRef: ref
})));