import React from "react";
import { Dropdown, DropdownMenu } from "@react-components/dropdown";
import { createRef, forwardRef } from "react";
import { render, waitFor } from "@testing-library/react";
const SimpleDropdownMenu = /*#__PURE__*/forwardRef((_ref, ref) => {
  let rest = Object.assign({}, _ref);
  return /*#__PURE__*/React.createElement(DropdownMenu, Object.assign({}, rest, {
    ref: ref
  }), /*#__PURE__*/React.createElement(Dropdown.Item, null, "New"), /*#__PURE__*/React.createElement(Dropdown.Item, null, "Open..."), /*#__PURE__*/React.createElement(Dropdown.Item, null, "Save as..."));
}); // ***** API *****

test("spread additional props on the root element", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleDropdownMenu, {
    ref: ref,
    "data-extra-props-test": "works"
  }));
  await waitFor(() => expect(ref.current.getAttribute("data-extra-props-test")).toBe("works"));
}); // ***** Refs *****

test("ref is a DOM element", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleDropdownMenu, {
    ref: ref
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("DIV");
});
test("using a callback ref, ref is a DOM element", async () => {
  let refNode = null;
  render( /*#__PURE__*/React.createElement(SimpleDropdownMenu, {
    ref: node => {
      refNode = node;
    }
  }));
  await waitFor(() => expect(refNode).not.toBeNull());
  expect(refNode instanceof HTMLElement).toBeTruthy();
  expect(refNode.tagName).toBe("DIV");
});
test("set ref once", async () => {
  const handler = jest.fn();
  render( /*#__PURE__*/React.createElement(SimpleDropdownMenu, {
    ref: handler
  }));
  await waitFor(() => expect(handler).toHaveBeenCalledTimes(1));
});