import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { Button } from "@react-components/button";
import { ButtonPopper } from "@react-components/popper";
import { act, render, waitFor } from "@testing-library/react";
import { createRef, forwardRef } from "react";
import userEvent from "@utils/user-event";
const BUTTON_ID = "button";
const POPPER_ID = "popper-wrapper";
const SimpleButtonPopper = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    button = /*#__PURE__*/React.createElement(Button, null, "Click me")
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["button"]);

  return /*#__PURE__*/React.createElement(ButtonPopper, Object.assign({}, rest, {
    button: button,
    ref: ref
  }), /*#__PURE__*/React.createElement("div", null, "Popper"));
}); // ***** Behaviors *****

test("show the popper on button click", async () => {
  const {
    getByTestId
  } = render( /*#__PURE__*/React.createElement(SimpleButtonPopper, null));
  act(() => {
    userEvent.click(getByTestId(BUTTON_ID));
  });
  await waitFor(() => expect(getByTestId(POPPER_ID)).toBeInTheDocument());
});
test("hide the popper on button click", async () => {
  const {
    getByTestId
  } = render( /*#__PURE__*/React.createElement(SimpleButtonPopper, null));
  act(() => {
    userEvent.click(getByTestId(BUTTON_ID));
  });
  const popperNode = await waitFor(() => getByTestId(POPPER_ID));
  act(() => {
    userEvent.click(getByTestId(BUTTON_ID));
  });
  await waitFor(() => expect(popperNode).not.toBeInTheDocument());
}); // ***** Refs *****

test("ref is a DOM element", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleButtonPopper, {
    ref: ref
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("DIV");
  expect(ref.current.getAttribute("data-testid")).toBe("popper-trigger");
});
test("using a callback ref, ref is a DOM element", async () => {
  let refNode = null;
  render( /*#__PURE__*/React.createElement(SimpleButtonPopper, {
    ref: node => {
      refNode = node;
    }
  }));
  await waitFor(() => expect(refNode).not.toBeNull());
  expect(refNode instanceof HTMLElement).toBeTruthy();
  expect(refNode.tagName).toBe("DIV");
  expect(refNode.getAttribute("data-testid")).toBe("popper-trigger");
});
test("can assign a ref to a button", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleButtonPopper, {
    button: /*#__PURE__*/React.createElement(Button, {
      ref: ref
    }, "Click me")
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("BUTTON");
});