import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { Button } from "@react-components/button";
import { CrossIcon } from "@react-components/icons";
import { TextInput } from "@react-components/text-input";
import { TextInputPopper } from "@react-components/popper";
import { act, render, waitFor } from "@testing-library/react";
import { createRef, forwardRef } from "react";
import userEvent from "@utils/user-event";
const POPPER_ID = "popper-wrapper";
const SimpleTextInputPopper = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    input = /*#__PURE__*/React.createElement(TextInput, null)
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["input"]);

  return /*#__PURE__*/React.createElement(TextInputPopper, Object.assign({}, rest, {
    input: input,
    ref: ref
  }), /*#__PURE__*/React.createElement("div", null, "Popper"));
});

function getInput(getByTestId) {
  return getByTestId("input").querySelector("input");
} // ***** Behaviors *****


test("show the popper on input click", async () => {
  const {
    getByTestId
  } = render( /*#__PURE__*/React.createElement(SimpleTextInputPopper, null));
  act(() => {
    userEvent.click(getInput(getByTestId));
  });
  await waitFor(() => expect(getByTestId(POPPER_ID)).toBeInTheDocument());
});
test("hide the popper on input click", async () => {
  const {
    getByTestId
  } = render( /*#__PURE__*/React.createElement(SimpleTextInputPopper, null));
  const inputNode = getInput(getByTestId);
  act(() => {
    userEvent.click(inputNode);
  });
  const popperNode = await waitFor(() => getByTestId(POPPER_ID));
  act(() => {
    userEvent.click(inputNode);
  });
  await waitFor(() => expect(popperNode).not.toBeInTheDocument());
});
test("dont close the popper on input clear button click", async () => {
  const {
    getByTestId
  } = render( /*#__PURE__*/React.createElement(SimpleTextInputPopper, {
    input: /*#__PURE__*/React.createElement(TextInput, {
      button: /*#__PURE__*/React.createElement(Button, {
        icon: /*#__PURE__*/React.createElement(CrossIcon, null)
      })
    })
  }));
  act(() => {
    userEvent.click(getInput(getByTestId));
  });
  const popperNode = await waitFor(() => getByTestId(POPPER_ID));
  act(() => {
    userEvent.click(getByTestId("clear-button"));
  });
  await waitFor(() => expect(popperNode).toBeInTheDocument());
}); // ***** Refs *****

test("ref is a DOM element", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleTextInputPopper, {
    ref: ref
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("DIV");
  expect(ref.current.getAttribute("data-testid")).toBe("popper-trigger");
});
test("using a callback ref, ref is a DOM element", async () => {
  let refNode = null;
  render( /*#__PURE__*/React.createElement(SimpleTextInputPopper, {
    ref: node => {
      refNode = node;
    }
  }));
  await waitFor(() => expect(refNode).not.toBeNull());
  expect(refNode instanceof HTMLElement).toBeTruthy();
  expect(refNode.tagName).toBe("DIV");
  expect(refNode.getAttribute("data-testid")).toBe("popper-trigger");
});
test("can assign a ref to a text input", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleTextInputPopper, {
    input: /*#__PURE__*/React.createElement(TextInput, {
      ref: ref
    })
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("DIV");
  expect(ref.current.getAttribute("data-testid")).toBe("input");
});
test("can assign a ref to a text input having a button", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleTextInputPopper, {
    input: /*#__PURE__*/React.createElement(TextInput, {
      button: /*#__PURE__*/React.createElement(Button, {
        icon: /*#__PURE__*/React.createElement(CrossIcon, null)
      }),
      ref: ref
    })
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("DIV");
  expect(ref.current.getAttribute("data-testid")).toBe("input");
});
test("can assign a ref to a text input button", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleTextInputPopper, {
    input: /*#__PURE__*/React.createElement(TextInput, {
      button: /*#__PURE__*/React.createElement(Button, {
        icon: /*#__PURE__*/React.createElement(CrossIcon, null),
        ref: ref
      })
    })
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("BUTTON");
});