import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { AddIcon } from "@react-components/icons";
import { TagsPicker, tagsPickerItem } from "@react-components/tags-picker";
import { createChromaticSection, paramsBuilder, storiesOfBuilder } from "@utils";
import { noop } from "lodash";
const GROUP_CREATED_VALUE = "group-created";
const GROUP_RESTORED_VALUE = "group-restored";
const GROUP_DELETED_VALUE = "group-deleted";
const GROUP_NAME_CHANGED_VALUE = "group-name-changed";
const GROUP_PRIVACY_CHANGED_VALUE = "group-privacy-changed";
const DEFAULT_ITEMS = [tagsPickerItem("Created", GROUP_CREATED_VALUE), tagsPickerItem("Restored", GROUP_RESTORED_VALUE), tagsPickerItem("Deleted", GROUP_DELETED_VALUE), tagsPickerItem("Name Changed", GROUP_NAME_CHANGED_VALUE), tagsPickerItem("Privacy Changed", GROUP_PRIVACY_CHANGED_VALUE)];
const DEFAULT_ITEMS_WITH_CATEGORIES = [tagsPickerItem("Created", GROUP_CREATED_VALUE, "Group Lifecycle"), tagsPickerItem("Restored", GROUP_RESTORED_VALUE, "Group Lifecycle"), tagsPickerItem("Deleted", GROUP_DELETED_VALUE, "Collaboration"), tagsPickerItem("Name Changed", GROUP_NAME_CHANGED_VALUE, "Collaboration"), tagsPickerItem("Privacy Changed", GROUP_PRIVACY_CHANGED_VALUE, "Others")];

function stories(segment) {
  return storiesOfBuilder(module, createChromaticSection("TagsPicker")).segment(segment).parameters(paramsBuilder().chromaticDelay(100).build()).build();
}

function createTagsPicker(_ref = {}) {
  let {
    items = DEFAULT_ITEMS
  } = _ref,
      otherProps = _objectWithoutProperties(_ref, ["items"]);

  return /*#__PURE__*/React.createElement(TagsPicker, Object.assign({
    items: items,
    onValuesChange: noop
  }, otherProps));
}

createTagsPicker.displayName = "createTagsPicker";
stories().add("opened", () => createTagsPicker({
  open: true
})).add("default opened", () => createTagsPicker({
  defaultOpen: true
})).add("size", () => /*#__PURE__*/React.createElement("div", {
  className: "flex flex-column"
}, /*#__PURE__*/React.createElement("div", {
  className: "flex",
  style: {
    marginBottom: "150px"
  }
}, createTagsPicker({
  size: "small",
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE]
})), /*#__PURE__*/React.createElement("div", {
  className: "flex",
  style: {
    marginBottom: "150px"
  }
}, createTagsPicker({
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE]
})), /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, createTagsPicker({
  size: "large",
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE]
})))).add("interaction states", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, createTagsPicker({
  active: true,
  className: "mr5"
}), createTagsPicker({
  focus: true,
  className: "mr5"
}), createTagsPicker({
  hover: true,
  className: "mr5"
}), createTagsPicker({
  focus: true,
  hover: true
})));
stories("/dropdown").add("some items", () => createTagsPicker({
  defaultOpen: true
})).add("no items", () => createTagsPicker({
  items: [],
  defaultOpen: true
})).add("categories", () => createTagsPicker({
  items: DEFAULT_ITEMS_WITH_CATEGORIES,
  defaultOpen: true
}));
stories("/selected values").add("no selection", () => createTagsPicker()).add("some values selected", () => createTagsPicker({
  values: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE]
})).add("all values selected", () => createTagsPicker({
  values: DEFAULT_ITEMS.map(x => x.value)
}));
stories("/selected values/clear button").add("can clear when all values selected", () => createTagsPicker({
  values: DEFAULT_ITEMS.map(x => x.value)
})).add("cannot clear when no selection", () => createTagsPicker({
  values: []
}));
stories("/selected values/add button").add("can add when no selection", () => createTagsPicker({
  values: []
})).add("can add when all values selected", () => createTagsPicker({
  values: DEFAULT_ITEMS.map(x => x.value)
}));
stories("/default values").add("some values selected", () => createTagsPicker({
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE]
})).add("all values selected", () => createTagsPicker({
  defaultValues: DEFAULT_ITEMS.map(x => x.value)
}));
stories("/disabled").add("values selected", () => createTagsPicker({
  defaultValues: [GROUP_RESTORED_VALUE, GROUP_NAME_CHANGED_VALUE],
  disabled: true
})).add("no selection", () => createTagsPicker({
  disabled: true
}));
stories("/customization").add("dropdown", () => createTagsPicker({
  dropdown: /*#__PURE__*/React.createElement(TagsPicker.Dropdown, {
    className: "bg-red border-red"
  })
})).add("no results message", () => createTagsPicker({
  items: [],
  noResultsMessage: "Custom no results message",
  defaultOpen: true
})).add("add text", () => createTagsPicker({
  addText: "Custom add text"
})).add("trigger", () => createTagsPicker({
  dropdown: /*#__PURE__*/React.createElement(TagsPicker.Dropdown, {
    trigger: /*#__PURE__*/React.createElement(TagsPicker.Trigger, {
      className: "bg-red"
    })
  })
})).add("trigger icon", () => createTagsPicker({
  dropdown: /*#__PURE__*/React.createElement(TagsPicker.Dropdown, {
    triggerIcon: /*#__PURE__*/React.createElement(AddIcon, {
      className: "fill-red"
    })
  })
})).add("search input element", () => createTagsPicker({
  dropdown: /*#__PURE__*/React.createElement(TagsPicker.Dropdown, {
    searchInput: /*#__PURE__*/React.createElement(TagsPicker.SearchInput, {
      className: "border-red"
    })
  }),
  defaultOpen: true
})).add("search input object", () => createTagsPicker({
  dropdown: /*#__PURE__*/React.createElement(TagsPicker.Dropdown, {
    searchInput: {
      className: "border-red"
    }
  }),
  defaultOpen: true
})).add("placeholder", () => createTagsPicker({
  placeholder: "Custom placeholder",
  defaultOpen: true
})).add("selected items components", () => createTagsPicker({
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE],
  selectedItemsComponent: /*#__PURE__*/React.createElement(TagsPicker.SelectedItems, {
    className: "bg-red border-red"
  })
})).add("selected item renderer", () => createTagsPicker({
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE],
  selectedItemsComponent: /*#__PURE__*/React.createElement(TagsPicker.SelectedItems, {
    itemRenderer: item => /*#__PURE__*/React.createElement("div", null, item.text)
  })
})).add("clear button", () => createTagsPicker({
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE],
  clearButton: /*#__PURE__*/React.createElement(TagsPicker.ClearButton, {
    className: "bg-red"
  })
})).add("clear text", () => createTagsPicker({
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE],
  clearButton: /*#__PURE__*/React.createElement(TagsPicker.ClearButton, {
    text: "Custom clear text"
  })
})).add("styling", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, createTagsPicker({
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE],
  className: "bg-red mr5"
}), createTagsPicker({
  defaultValues: [GROUP_NAME_CHANGED_VALUE, GROUP_RESTORED_VALUE],
  style: {
    backgroundColor: "red"
  }
})));