import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { SemanticRef, mergeClasses, useAutofocus, useMergedRefs } from "../../shared";
import { TextArea as SemanticTextArea } from "semantic-ui-react";
import { bool, number, oneOf, string } from "prop-types";
import { forwardRef } from "react";
import { isNil } from "lodash";
const propTypes = {
  /**
   * The value of the textarea.
   */
  value: string,

  /**
   * The default value of the textarea.
   */
  defaultValue: string,

  /**
   * Whether or not the textarea should autofocus on render.
   */
  autofocus: bool,

  /**
   * Delay before trying to autofocus.
   */
  autofocusDelay: number,

  /**
   * A textarea can have different sizes.
  */
  size: oneOf(["small", "medium", "large"]),

  /**
   * Whether or not the textarea take up the width of its container
   */
  fluid: bool,

  /**
   * A textarea can show that the data contains errors.
   */
  error: bool,

  /**
   * Whether or not the textarea is transparent.
   */
  transparent: bool,

  /**
   * Whether or not the textarea is resizable.
   */
  resizable: bool
};
export function InnerTextArea(props) {
  const {
    autofocus,
    autofocusDelay,
    size,
    error,
    fluid,
    transparent,
    resizable,
    active,
    focus,
    hover,
    disabled,
    className,
    children,
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["autofocus", "autofocusDelay", "size", "error", "fluid", "transparent", "resizable", "active", "focus", "hover", "disabled", "className", "children", "forwardedRef"]);

  const innerRef = useMergedRefs(forwardedRef);

  const setFocus = () => {
    if (!isNil(innerRef.current)) {
      innerRef.current.focus();
    }
  };

  const autofocusProps = useAutofocus(autofocus, autofocusDelay, disabled, setFocus);
  return /*#__PURE__*/React.createElement(SemanticRef, {
    innerRef: innerRef
  }, /*#__PURE__*/React.createElement(SemanticTextArea, Object.assign({}, rest, autofocusProps, {
    disabled: disabled,
    className: mergeClasses("ui textarea", error && "error", fluid && "fluid", active && "active", focus && "focus", hover && "hover", transparent && "transparent", resizable && "resizable", size && size, className)
  }), children));
}
InnerTextArea.displayName = "InnerTextArea";
InnerTextArea.propTypes = propTypes;
export const TextArea = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerTextArea, Object.assign({}, props, {
  forwardedRef: ref
})));