import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { Checkbox } from "../../checkbox";
import { SemanticRef } from "../../shared";
import { arrayOf, bool, element, number, object, oneOf, oneOfType, string } from "prop-types";
import { forwardRef } from "react";
const UNSUPPORTED_PROPS = ["defaultIndeterminate", "indeterminate", "slider", "radio", "type"]; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise the props will not render properly in the docs.

export const CHECKBOX_PROP_TYPES = {
  /**
   * Whether or not the toggle should autofocus on render.
   */
  autofocus: bool,

  /**
   * Delay before trying to autofocus.
   */
  autofocusDelay: number,

  /**
   * The text associated to the checkbox.
   */
  text: string,

  /**
   * [Shorthand](/?path=/docs/getting-started-shorthand-props--page) to display [icons](/?path=/docs/components-icon--default-story) after the text.
   */
  icons: oneOfType([element, arrayOf(element)]),

  /**
   * [Shorthand](/?path=/docs/getting-started-shorthand-props--page) to display a [label](/?path=/docs/components-label--default-story) after the text.
   */
  label: oneOfType([element, object]),

  /**
   * [Shorthand](/?path=/docs/getting-started-shorthand-props--page) to display a [count](/?path=/docs/components-count--default-story) after the text.
   */
  count: oneOfType([element, object]),

  /**
   * A toggle can vary in sizes.
   */
  size: oneOf(["small", "medium", "large"])
};
export function InnerToggle(props) {
  const {
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["forwardedRef"]);

  return /*#__PURE__*/React.createElement(SemanticRef, {
    innerRef: forwardedRef
  }, /*#__PURE__*/React.createElement(Checkbox, Object.assign({}, rest, {
    toggle: true,
    __componentName: "@orbit-ui/react-components/Toggle",
    __unsupportedProps: UNSUPPORTED_PROPS
  })));
}
InnerToggle.displayName = "InnerToggle";
InnerToggle.propTypes = CHECKBOX_PROP_TYPES;
export const Toggle = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(InnerToggle, Object.assign({}, props, {
  forwardedRef: ref
})));