import React from "react";
import { Tooltip } from "@react-components/tooltip";
import { createRef, forwardRef } from "react";
import { render, waitFor } from "@testing-library/react";
const SimpleTooltip = /*#__PURE__*/forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(Tooltip, Object.assign({}, props, {
    content: "Adds users to your feed",
    open: true,
    trigger: /*#__PURE__*/React.createElement("span", null, "Add"),
    ref: ref
  }));
}); // ***** Refs *****

test("ref is a DOM element", async () => {
  const ref = /*#__PURE__*/createRef();
  render( /*#__PURE__*/React.createElement(SimpleTooltip, {
    ref: ref
  }));
  await waitFor(() => expect(ref.current).not.toBeNull());
  expect(ref.current instanceof HTMLElement).toBeTruthy();
  expect(ref.current.tagName).toBe("DIV");
});
test("when using a callback ref, ref is a DOM element", async () => {
  let refNode = null;
  render( /*#__PURE__*/React.createElement(SimpleTooltip, {
    ref: node => {
      refNode = node;
    }
  }));
  await waitFor(() => expect(refNode).not.toBeNull());
  expect(refNode instanceof HTMLElement).toBeTruthy();
  expect(refNode.tagName).toBe("DIV");
});
test("set ref once", async () => {
  const handler = jest.fn();
  render( /*#__PURE__*/React.createElement(SimpleTooltip, {
    ref: handler
  }));
  await waitFor(() => expect(handler).toHaveBeenCalledTimes(1));
});